<h1 align="center">Welcome to the NLP Annotation Framework <code>(NlpAF)</code> </h1>

<p align="center">
  <a href="https://github.com/roxanneelbaff/nlp-annotation-framework/blob/master/LICENSE">
    <img alt="License: MIT" src="https://img.shields.io/badge/license-MIT-yellow.svg" target="_blank" />
  </a>
  <a href="https://img.shields.io/badge/Made%20with-Python-1f425f.svg">
    <img src="https://img.shields.io/badge/Made%20with-Python-1f425f.svg" alt="Badge: Made with Python"/>
  </a>
  <a href="https://pypi.org/project/nlpaf/"><img src="https://badge.fury.io/py/nlpaf.svg" alt="Badge: PyPI version" ></a>

  <a href="https://open.vscode.dev/roxanneelbaff/nlp-annotation-framework">
    <img alt="Badge: Open in VSCode" src="https://img.shields.io/static/v1?logo=visualstudiocode&label=&message=open%20in%20visual%20studio%20code&labelColor=2c2c32&color=007acc&logoColor=007acc" target="_blank" />
  </a>
<!--  <a href="https://citation-file-format.github.io/">
    <img alt="Badge: Citation File Format Inside" src="https://img.shields.io/badge/-citable%20software-green" target="_blank" />
  </a>-->
</p>

> `nlpaf` is a Python Library offering an architectural framework and tools to extract features from textual data.

____

## Installation

### Direct install via pip 

The package can also be installed directly via pip.
```
pip install nlpaf
```

### Manual cloning
Clone the repository, go to the root folder and then run:

```
pip install -e .
```